Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var http_1 = require("@angular/http");
var Observable_1 = require("rxjs/Observable");
require("rxjs/add/observable/fromPromise");
var ns_file_system_1 = require("../file-system/ns-file-system");
var NSXSRFStrategy = /** @class */ (function () {
    function NSXSRFStrategy() {
    }
    NSXSRFStrategy.prototype.configureRequest = function (_req) {
        // noop
    };
    return NSXSRFStrategy;
}());
exports.NSXSRFStrategy = NSXSRFStrategy;
var NSHttp = /** @class */ (function (_super) {
    __extends(NSHttp, _super);
    function NSHttp(backend, defaultOptions, nsFileSystem) {
        var _this = _super.call(this, backend, defaultOptions) || this;
        _this.nsFileSystem = nsFileSystem;
        return _this;
    }
    /**
     * Performs a request with `request` http method.
     */
    NSHttp.prototype.request = function (req, options) {
        var urlString = typeof req === "string" ? req : req.url;
        if (isLocalRequest(urlString)) {
            return this._requestLocalUrl(urlString);
        }
        else {
            return _super.prototype.request.call(this, req, options);
        }
    };
    /**
     * Performs a request with `get` http method.
     */
    NSHttp.prototype.get = function (url, options) {
        if (isLocalRequest(url)) {
            return this._requestLocalUrl(url);
        }
        else {
            return _super.prototype.get.call(this, url, options);
        }
    };
    /**
     * Uses a local file if `~/` resource is requested.
     * @param url
     */
    NSHttp.prototype._requestLocalUrl = function (url) {
        var _this = this;
        // normalize url
        url = normalizeLocalUrl(url);
        // request from local app resources
        return Observable_1.Observable.fromPromise(new Promise(function (resolve, reject) {
            var app = _this.nsFileSystem.currentApp();
            var localFile = app.getFile(url);
            if (localFile) {
                localFile.readText().then(function (data) {
                    resolve(responseOptions(data, 200, url));
                }, function (err) {
                    reject(responseOptions(err, 400, url));
                });
            }
            else {
                reject(responseOptions("Not Found", 404, url));
            }
        }));
    };
    NSHttp = __decorate([
        core_1.Injectable(),
        __metadata("design:paramtypes", [http_1.ConnectionBackend, http_1.RequestOptions, ns_file_system_1.NSFileSystem])
    ], NSHttp);
    return NSHttp;
}(http_1.Http));
exports.NSHttp = NSHttp;
function isLocalRequest(url) {
    return url.indexOf("~") === 0 || url.indexOf("/") === 0;
}
function normalizeLocalUrl(url) {
    return url.replace("~", "").replace("/", "");
}
function responseOptions(body, status, url) {
    return new http_1.Response(new http_1.ResponseOptions({
        body: body,
        status: status,
        statusText: "OK",
        type: status === 200 ? http_1.ResponseType.Default : http_1.ResponseType.Error,
        url: url
    }));
}
//# sourceMappingURL=ns-http.js.map